/*

    QBabbel, a simple VoIP chat utility using JVOIPLIB 
    Copyright (C) 2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "qbabbelinput.h"
#include <math.h>

QBabbelInput::QBabbelInput(JVOIPSession *sess) : JVOIPSoundcardInput(sess)
{
	avg = 0;
	avgmutex.Init();
}

QBabbelInput::~QBabbelInput()
{
}

double QBabbelInput::GetSampleAverage()
{
	double a;
	
	avgmutex.Lock();
	a = avg;
	avgmutex.Unlock();
	return a;
}

int QBabbelInput::GetSampleBlock(VoIPFramework::VoiceBlock *vb)
{
	int status;
	int i,num;
	double val;
	unsigned char *data;
	
	status = JVOIPSoundcardInput::GetSampleBlock(vb);
	if (status < 0)
		return status;
	
	val = 0;
	num = vb->GetNumBytes();
	data = vb->GetSamples(false);
	if (vb->GetBytesPerSample() == 1)
	{
		double curval;
		
		for (i = 0 ; i < num ; i++)
		{
			curval = ((double)data[i])-128.0;
			if (curval < 0)
				curval = -curval;
			val += log(curval+1.0);
		}
		val /= (double)num;
		val /= log(128.0+1);
	}
	else
	{
		// TODO;
	}

	avgmutex.Lock();
	avg = val;
	avgmutex.Unlock();
	return 0;
}


